==> haskell-foldl-1.4.18-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldl
version:              1.4.18
visibility:           public
id:                   foldl-1.4.18-6vPlA7jeSqwAJugBXA3XZ5
key:                  foldl-1.4.18-6vPlA7jeSqwAJugBXA3XZ5
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  ae18161af94c3607cb133eba55a5f18d
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/foldl-1.4.18
library-dirs:         /usr/lib/ghc-9.4.8/site-local/foldl-1.4.18
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/foldl-1.4.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.18-6vPlA7jeSqwAJugBXA3XZ5
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    comonad-5.0.9-Ii5hgdheJL2Zm3d3qSYJo containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    hashable-1.4.5.0-EdCBZmCkEma7WCMhhvMdNf
    primitive-0.9.1.0-Fzohuuo3yXQHgF9SkKDO4d
    profunctors-5.6.3-JPsyxucHO7GE5uSKcotJO6
    random-1.2.1.3-BS01zQf871D7daMTFQ0UbO
    semigroupoids-6.0.1-CiyJpZ8oNNEK3LiWeue5 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-KWLixwBKCEK6ORqUSVo2CW
    vector-0.13.2.0-BnQJYTBpbJKJ2sldbPuyJj

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.18-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldl
version:              1.4.18
visibility:           public
id:                   foldl-1.4.18-9r1tegvomCs27asbyylpUA
key:                  foldl-1.4.18-9r1tegvomCs27asbyylpUA
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  bc422d371843416eb57e08911971d855
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/foldl-1.4.18
library-dirs:         /usr/lib/ghc-9.4.8/site-local/foldl-1.4.18
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/foldl-1.4.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.18-9r1tegvomCs27asbyylpUA
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    comonad-5.0.9-DbocoRZxFWPanrrsdFCv7 containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    hashable-1.4.5.0-tUQ3ISdCwwAzRS3LRBhXn
    primitive-0.9.1.0-F4HGYkgYEkOLs7asiZIPNd
    profunctors-5.6.3-HIGdidN5O0T3CUcdAW2Doh
    random-1.2.1.3-FjAccEVuGQcK7S7DSNXHmd
    semigroupoids-6.0.1-EtstizQFZrIGQw5mSEZWn3 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Kt9XOM1GYdv4KClqugAe9a
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
